# Live Trading With AutoTrader

What use would backtesting be if you can't take the same strategy live? This is no concern when you use 
AutoTrader, which features a seamless transition from backtesting to livetrading. Simply run your
strategy through AutoTrader, and it will be live.


## Supported Brokers
AutoTrader currently supports Oanda and Interactive Brokers for livetrading.


